Documentation
¶
Index ¶
- Constants
- Variables
- func GetResourceReadBPSValue(limit corev1.ResourceList) int64
- func GetResourceReadIOPSValue(limit corev1.ResourceList) int64
- func GetResourceWriteBPSValue(limit corev1.ResourceList) int64
- func GetResourceWriteIOPSValue(limit corev1.ResourceList) int64
- func ResourceBlkioValueStr(limit corev1.ResourceList) (string, bool)
- type ConfigMapValueSource
- type ExtendedResourceRequirements
- type PartialObjectMeta
- type Value
- type ValueFrom
Constants ¶
const ( ResourceIOPS corev1.ResourceName = "iops" ResourceBPS corev1.ResourceName = "bps" ResourceReadIOPS corev1.ResourceName = "iops.read" ResourceWriteIOPS corev1.ResourceName = "iops.write" ResourceReadBPS corev1.ResourceName = "bps.read" ResourceWriteBPS corev1.ResourceName = "bps.write" )
const Unlimited int64 = -1
Variables ¶
var ExtendedResource = []corev1.ResourceName{ ResourceIOPS, ResourceBPS, ResourceReadIOPS, ResourceWriteIOPS, ResourceReadBPS, ResourceWriteBPS, }
Functions ¶
func GetResourceReadBPSValue ¶
func GetResourceReadBPSValue(limit corev1.ResourceList) int64
func GetResourceReadIOPSValue ¶
func GetResourceReadIOPSValue(limit corev1.ResourceList) int64
func GetResourceWriteBPSValue ¶
func GetResourceWriteBPSValue(limit corev1.ResourceList) int64
func GetResourceWriteIOPSValue ¶
func GetResourceWriteIOPSValue(limit corev1.ResourceList) int64
func ResourceBlkioValueStr ¶
func ResourceBlkioValueStr(limit corev1.ResourceList) (string, bool)
Types ¶
type ConfigMapValueSource ¶
type ConfigMapValueSource struct {
corev1.LocalObjectReference `json:",inline" protobuf:"bytes,1,opt,name=localObjectReference"`
// Key of the config map
// +optional
Key string `json:"key,omitempty"`
}
ConfigMapValueSource defines a config map datasource.
func (*ConfigMapValueSource) DeepCopy ¶
func (in *ConfigMapValueSource) DeepCopy() *ConfigMapValueSource
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ConfigMapValueSource.
func (*ConfigMapValueSource) DeepCopyInto ¶
func (in *ConfigMapValueSource) DeepCopyInto(out *ConfigMapValueSource)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ExtendedResourceRequirements ¶
type ExtendedResourceRequirements struct {
corev1.ResourceRequirements `json:",inline"`
LimitsIO corev1.ResourceList `json:"limits.io,omitempty"`
}
func (*ExtendedResourceRequirements) DeepCopy ¶
func (in *ExtendedResourceRequirements) DeepCopy() *ExtendedResourceRequirements
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExtendedResourceRequirements.
func (*ExtendedResourceRequirements) DeepCopyInto ¶
func (in *ExtendedResourceRequirements) DeepCopyInto(out *ExtendedResourceRequirements)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PartialObjectMeta ¶
type PartialObjectMeta struct {
// Map of string keys and values that can be used to organize and categorize
// (scope and select) objects. May match selectors of replication controllers
// and services.
// More info: http://kubernetes.io/docs/user-guide/labels
// +optional
Labels map[string]string `json:"labels,omitempty" protobuf:"bytes,4,rep,name=labels"`
// Annotations is an unstructured key value map stored with a resource that may be
// set by external tools to store and retrieve arbitrary metadata. They are not
// queryable and should be preserved when modifying objects.
// More info: http://kubernetes.io/docs/user-guide/annotations
// +optional
Annotations map[string]string `json:"annotations,omitempty" protobuf:"bytes,5,rep,name=annotations"`
}
PartialObjectMeta is a metadata only contains labels and annotations.
func (*PartialObjectMeta) DeepCopy ¶
func (in *PartialObjectMeta) DeepCopy() *PartialObjectMeta
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PartialObjectMeta.
func (*PartialObjectMeta) DeepCopyInto ¶
func (in *PartialObjectMeta) DeepCopyInto(out *PartialObjectMeta)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Value ¶
type Value struct {
// Value is the raw string value.
// +optional
Value *string `json:"value,omitempty"`
// ValueFrom is the value from external source.
ValueFrom *ValueFrom `json:"valueFrom,omitempty"`
}
Value defines a value.
func (*Value) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Value.
func (*Value) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Value) GetValueFrom ¶
type ValueFrom ¶
type ValueFrom struct {
// ConfigMap value source. Ignored if not found.
// +optional
ConfigMap *ConfigMapValueSource `json:"configMap,omitempty"`
}
ValueFrom defines a value from various external sources.
func (*ValueFrom) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ValueFrom.
func (*ValueFrom) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.