Documentation
¶
Index ¶
- type CDCTemplate
- type CNConfig
- type CNStaticConfig
- type CNTemplate
- type ClusterReplicasStatus
- type Condition
- type ConditionType
- type Config
- type DNConfig
- type MonitorStatus
- type NodeSelectorItem
- type NodeSelectorReference
- type Phase
- type PrivilegeItem
- type PrivilegeType
- type ReplicaStatusForPrint
- type ReplicasStatus
- type RestoreSpec
- type Security
- type SpecSnapshot
- type Stage
- type StatelessTopologyRuleItem
- type StatusForPrint
- type TLS
- type Topology
- type TopologyNodeCDC
- type TopologyNodeCN
- type TopologyNodeDN
- type TopologyNodeGMS
- type TopologyNodes
- type TopologyRuleComponents
- type TopologyRules
- type UpgradeStrategyType
- type XStoreTemplate
- type XStoreTopologyRule
- type XStoreTopologyRuleNodeSetItem
- type XStoreTopologyRuleRolling
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CDCTemplate ¶
type CDCTemplate struct {
// Image for CDC. Should be replaced by default value if not present.
// +optional
Image string `json:"image,omitempty"`
// ImagePullPolicy describes a policy for if/when to pull a container image (especially
// for the engine container).
ImagePullPolicy corev1.PullPolicy `json:"imagePullPolicy,omitempty"`
// ImagePullSecrets represents the secrets for pulling private images.
ImagePullSecrets []corev1.LocalObjectReference `json:"imagePullSecrets,omitempty"`
// HostNetwork mode.
// +optional
HostNetwork bool `json:"hostNetwork,omitempty"`
// Resources. Default is limits of 4 cpu and 8Gi memory.
Resources corev1.ResourceRequirements `json:"resources,omitempty"`
}
func (*CDCTemplate) DeepCopy ¶
func (in *CDCTemplate) DeepCopy() *CDCTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CDCTemplate.
func (*CDCTemplate) DeepCopyInto ¶
func (in *CDCTemplate) DeepCopyInto(out *CDCTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CNConfig ¶
type CNConfig struct {
Dynamic map[string]intstr.IntOrString `json:"dynamic,omitempty"`
Static *CNStaticConfig `json:"static,omitempty"`
}
func (*CNConfig) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CNConfig.
func (*CNConfig) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CNStaticConfig ¶
type CNStaticConfig struct {
EnableCoroutine bool `json:"EnableCoroutine,omitempty"`
EnableReplicaRead bool `json:"EnableReplicaRead,omitempty"`
EnableJvmRemoteDebug bool `json:"EnableJvmRemoteDebug,omitempty"`
ServerProperties map[string]intstr.IntOrString `json:"ServerProperties,omitempty"`
}
func (*CNStaticConfig) DeepCopy ¶
func (in *CNStaticConfig) DeepCopy() *CNStaticConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CNStaticConfig.
func (*CNStaticConfig) DeepCopyInto ¶
func (in *CNStaticConfig) DeepCopyInto(out *CNStaticConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CNTemplate ¶
type CNTemplate struct {
// Image for CN. Should be replaced by default value if not present.
// +optional
Image string `json:"image,omitempty"`
// ImagePullPolicy describes a policy for if/when to pull a container image (especially
// for the engine container).
ImagePullPolicy corev1.PullPolicy `json:"imagePullPolicy,omitempty"`
// ImagePullSecrets represents the secrets for pulling private images.
ImagePullSecrets []corev1.LocalObjectReference `json:"imagePullSecrets,omitempty"`
// HostNetwork mode.
// +optional
HostNetwork bool `json:"hostNetwork,omitempty"`
// Resources. Default is limits of 4 cpu and 8Gi memory.
Resources corev1.ResourceRequirements `json:"resources,omitempty"`
}
func (*CNTemplate) DeepCopy ¶
func (in *CNTemplate) DeepCopy() *CNTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CNTemplate.
func (*CNTemplate) DeepCopyInto ¶
func (in *CNTemplate) DeepCopyInto(out *CNTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterReplicasStatus ¶
type ClusterReplicasStatus struct {
// GMS defines the replica status for GMS.
GMS ReplicasStatus `json:"gms,omitempty"`
// CN defines the replica status for CN.
CN ReplicasStatus `json:"cn,omitempty"`
// DN defines the replica status for DN.
DN ReplicasStatus `json:"dn,omitempty"`
// CDC defines the replica status for CDC.
CDC *ReplicasStatus `json:"cdc,omitempty"`
}
ClusterReplicasStatus is a detailed replicas status of the cluster.
func (*ClusterReplicasStatus) DeepCopy ¶
func (in *ClusterReplicasStatus) DeepCopy() *ClusterReplicasStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterReplicasStatus.
func (*ClusterReplicasStatus) DeepCopyInto ¶
func (in *ClusterReplicasStatus) DeepCopyInto(out *ClusterReplicasStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Condition ¶
type Condition struct {
// Type is the type of the condition.
Type ConditionType `json:"type"`
// Status is the status of the condition.
Status corev1.ConditionStatus `json:"status"`
// Last time we probed the condition.
// +optional
LastProbeTime *metav1.Time `json:"lastProbeTime,omitempty"`
// Last time the condition transition from on status to another.
LastTransitionTime metav1.Time `json:"lastTransitionTime,omitempty"`
// Unique, one-word, CamelCase reason for the condition's last transition.
// +optional
Reason string `json:"reason,omitempty"`
// Human-readable message indicating details about last transition.
// +optional
Message string `json:"message,omitempty"`
}
Condition defines the condition and its status.
func (*Condition) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Condition.
func (*Condition) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConditionType ¶
type ConditionType string
ConditionType represents the condition type of the cluster.
const ( GmsReady ConditionType = "GmsReady" CnsReady ConditionType = "CnsReady" DnsReady ConditionType = "DnsReady" CdcReady ConditionType = "CdcReady" ClusterReady ConditionType = "ClusterReady" )
Valid condition types.
type Config ¶
type Config struct {
// CN config.
CN CNConfig `json:"cn,omitempty"`
// DN config.
DN DNConfig `json:"dn,omitempty"`
}
func (*Config) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Config.
func (*Config) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DNConfig ¶
type DNConfig struct {
MycnfOverwrite string `json:"mycnfOverwrite,omitempty"`
LogPurgeInterval metav1.Duration `json:"logPurgeInterval,omitempty"`
}
func (*DNConfig) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DNConfig.
func (*DNConfig) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MonitorStatus ¶
type MonitorStatus string
const ( MonitorStatusPending MonitorStatus = "" MonitorStatusCreating MonitorStatus = "Creating" MonitorStatusMonitoring MonitorStatus = "Monitoring" MonitorStatusUpdating MonitorStatus = "Updating" )
type NodeSelectorItem ¶
type NodeSelectorItem struct {
Name string `json:"name,omitempty"`
NodeSelector corev1.NodeSelector `json:"nodeSelector,omitempty"`
}
func (*NodeSelectorItem) DeepCopy ¶
func (in *NodeSelectorItem) DeepCopy() *NodeSelectorItem
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeSelectorItem.
func (*NodeSelectorItem) DeepCopyInto ¶
func (in *NodeSelectorItem) DeepCopyInto(out *NodeSelectorItem)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NodeSelectorReference ¶
type NodeSelectorReference struct {
Reference string `json:"reference,omitempty"`
NodeSelector *corev1.NodeSelector `json:"selector,omitempty"`
}
func (*NodeSelectorReference) DeepCopy ¶
func (in *NodeSelectorReference) DeepCopy() *NodeSelectorReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeSelectorReference.
func (*NodeSelectorReference) DeepCopyInto ¶
func (in *NodeSelectorReference) DeepCopyInto(out *NodeSelectorReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Phase ¶
type Phase string
Phase defines the operating phase of the cluster.
const ( PhaseNew Phase = "" PhasePending Phase = "Pending" PhaseCreating Phase = "Creating" PhaseRunning Phase = "Running" PhaseLocked Phase = "Locked" PhaseUpgrading Phase = "Upgrading" PhaseRestoring Phase = "Restoring" PhaseDeleting Phase = "Deleting" PhaseFailed Phase = "Failed" PhaseUnknown Phase = "Unknown" )
Valid phases.
type PrivilegeItem ¶
type PrivilegeItem struct {
// Username for the account.
Username string `json:"username,omitempty"`
// Password for the account. The operator will generate a
// random password if not provided.
Password string `json:"password,omitempty"`
// Type represents the type of privilege, default is ReadWrite.
// +optional
Type PrivilegeType `json:"type,omitempty"`
}
PrivilegeItem represents an item for privilege definition.
func (*PrivilegeItem) DeepCopy ¶
func (in *PrivilegeItem) DeepCopy() *PrivilegeItem
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PrivilegeItem.
func (*PrivilegeItem) DeepCopyInto ¶
func (in *PrivilegeItem) DeepCopyInto(out *PrivilegeItem)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PrivilegeType ¶
type PrivilegeType string
const ( ReadWrite PrivilegeType = "RW" ReadOnly PrivilegeType = "RO" DDLOnly PrivilegeType = "DDL" DMLOnly PrivilegeType = "DML" Super PrivilegeType = "SUPER" )
Valid privilege types.
type ReplicaStatusForPrint ¶
type ReplicaStatusForPrint struct {
// GMS status, e.g. 1/1
GMS string `json:"gms,omitempty"`
// CN status, e.g. 1/2
CN string `json:"cn,omitempty"`
// DN status, e.g. 1/2
DN string `json:"dn,omitempty"`
// CDC status, e.g. 1/2 or - when CDC nodes not requested.
CDC string `json:"cdc,omitempty"`
}
ReplicaStatusForPrint represents the printable status for replica status of nodes.
func (*ReplicaStatusForPrint) DeepCopy ¶
func (in *ReplicaStatusForPrint) DeepCopy() *ReplicaStatusForPrint
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ReplicaStatusForPrint.
func (*ReplicaStatusForPrint) DeepCopyInto ¶
func (in *ReplicaStatusForPrint) DeepCopyInto(out *ReplicaStatusForPrint)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ReplicasStatus ¶
type ReplicasStatus struct {
// Total defines the total size of the replica.
Total int32 `json:"total,omitempty"`
// Available represents how many replicas are currently available.
Available int32 `json:"available,omitempty"`
}
ReplicasStatus represents the replica status of replicas of some nodes.
func (*ReplicasStatus) DeepCopy ¶
func (in *ReplicasStatus) DeepCopy() *ReplicasStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ReplicasStatus.
func (*ReplicasStatus) DeepCopyInto ¶
func (in *ReplicasStatus) DeepCopyInto(out *ReplicasStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ReplicasStatus) Display ¶
func (rs *ReplicasStatus) Display() string
type RestoreSpec ¶
type RestoreSpec struct {
}
func (*RestoreSpec) DeepCopy ¶
func (in *RestoreSpec) DeepCopy() *RestoreSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RestoreSpec.
func (*RestoreSpec) DeepCopyInto ¶
func (in *RestoreSpec) DeepCopyInto(out *RestoreSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Security ¶
type Security struct {
// TLS defines the TLS config of the access port.
// +optional
TLS *TLS `json:"tls,omitempty"`
// EncodeKey defines the encode key used by the cluster. If not provided,
// operator will generate a random key.
// +optional
EncodeKey *corev1.SecretKeySelector `json:"encodeKey,omitempty"`
}
Security represents the security config of the cluster.
func (*Security) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Security.
func (*Security) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SpecSnapshot ¶
type SpecSnapshot struct {
Topology Topology `json:"topology,omitempty"`
Config Config `json:"config,omitempty"`
}
SpecSnapshot represents a snapshot of aspects of the spec.
func (*SpecSnapshot) DeepCopy ¶
func (in *SpecSnapshot) DeepCopy() *SpecSnapshot
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SpecSnapshot.
func (*SpecSnapshot) DeepCopyInto ¶
func (in *SpecSnapshot) DeepCopyInto(out *SpecSnapshot)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Stage ¶
type Stage string
Stage defines the operating stage of the cluster. Different phases may have different stages.
type StatelessTopologyRuleItem ¶
type StatelessTopologyRuleItem struct {
Name string `json:"name,omitempty"`
Replicas *intstr.IntOrString `json:"replicas,omitempty"`
NodeSelector *NodeSelectorReference `json:"selector,omitempty"`
}
func (*StatelessTopologyRuleItem) DeepCopy ¶
func (in *StatelessTopologyRuleItem) DeepCopy() *StatelessTopologyRuleItem
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StatelessTopologyRuleItem.
func (*StatelessTopologyRuleItem) DeepCopyInto ¶
func (in *StatelessTopologyRuleItem) DeepCopyInto(out *StatelessTopologyRuleItem)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type StatusForPrint ¶
type StatusForPrint struct {
// ReplicaStatus for the status of nodes' replicas.
ReplicaStatus ReplicaStatusForPrint `json:"replicaStatus,omitempty"`
// RebalanceProgress for the status of data rebalance tasks.
RebalanceProcess string `json:"rebalanceProcess,omitempty"`
// DetailedVersion for the status of current detailed vesrion of the cluster,
// which is dynamically acquired when cluster is ready.
DetailedVersion string `json:"detailedVersion,omitempty"`
// StorageSize represents the total storage size that used by this cluster.
// The value is in IEC format and is simply gotten by accumulating the GMS'
// and DNs' storage sizes.
StorageSize string `json:"storageSize,omitempty"`
// StorageSizeUpdateTime represents the last time that storage size is updated.
// It's used to control the frequency of the updating progress.
StorageSizeUpdateTime *metav1.Time `json:"storageSizeUpdateTime,omitempty"`
}
StatusForPrint represents the overall printable status of the cluster.
func (*StatusForPrint) DeepCopy ¶
func (in *StatusForPrint) DeepCopy() *StatusForPrint
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StatusForPrint.
func (*StatusForPrint) DeepCopyInto ¶
func (in *StatusForPrint) DeepCopyInto(out *StatusForPrint)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TLS ¶
type TLS struct {
// SecretName of the TLS config's secret.
SecretName string `json:"secretName,omitempty"`
// GenerateSelfSigned represents if let the operator generate and use a self-signed cert.
GenerateSelfSigned bool `json:"generateSelfSigned,omitempty"`
}
TLS defines the TLS config.
func (*TLS) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TLS.
func (*TLS) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Topology ¶
type Topology struct {
// Version defines the default image version of the all components. Default is empty.
// If not provided, one should specify the images manually.
// +optional
Version string `json:"version,omitempty"`
// Rules defines the topology rules of components of the cluster.
Rules TopologyRules `json:"rules,omitempty"`
// Node defines the replicas and template of components of the cluster.
Nodes TopologyNodes `json:"nodes,omitempty"`
}
func (*Topology) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Topology.
func (*Topology) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TopologyNodeCDC ¶
type TopologyNodeCDC struct {
Replicas int32 `json:"replicas,omitempty"`
Template CDCTemplate `json:"template,omitempty"`
}
func (*TopologyNodeCDC) DeepCopy ¶
func (in *TopologyNodeCDC) DeepCopy() *TopologyNodeCDC
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TopologyNodeCDC.
func (*TopologyNodeCDC) DeepCopyInto ¶
func (in *TopologyNodeCDC) DeepCopyInto(out *TopologyNodeCDC)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TopologyNodeCN ¶
type TopologyNodeCN struct {
Replicas int32 `json:"replicas,omitempty"`
Template CNTemplate `json:"template,omitempty"`
}
func (*TopologyNodeCN) DeepCopy ¶
func (in *TopologyNodeCN) DeepCopy() *TopologyNodeCN
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TopologyNodeCN.
func (*TopologyNodeCN) DeepCopyInto ¶
func (in *TopologyNodeCN) DeepCopyInto(out *TopologyNodeCN)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TopologyNodeDN ¶
type TopologyNodeDN struct {
Replicas int32 `json:"replicas,omitempty"`
Template XStoreTemplate `json:"template,omitempty"`
}
func (*TopologyNodeDN) DeepCopy ¶
func (in *TopologyNodeDN) DeepCopy() *TopologyNodeDN
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TopologyNodeDN.
func (*TopologyNodeDN) DeepCopyInto ¶
func (in *TopologyNodeDN) DeepCopyInto(out *TopologyNodeDN)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TopologyNodeGMS ¶
type TopologyNodeGMS struct {
// Template of GMS xstore. If not provided, the operator will use
// the template for DN as template for GMS.
Template *XStoreTemplate `json:"template,omitempty"`
}
func (*TopologyNodeGMS) DeepCopy ¶
func (in *TopologyNodeGMS) DeepCopy() *TopologyNodeGMS
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TopologyNodeGMS.
func (*TopologyNodeGMS) DeepCopyInto ¶
func (in *TopologyNodeGMS) DeepCopyInto(out *TopologyNodeGMS)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TopologyNodes ¶
type TopologyNodes struct {
GMS TopologyNodeGMS `json:"gms,omitempty"`
CN TopologyNodeCN `json:"cn,omitempty"`
DN TopologyNodeDN `json:"dn,omitempty"`
CDC *TopologyNodeCDC `json:"cdc,omitempty"`
}
func (*TopologyNodes) DeepCopy ¶
func (in *TopologyNodes) DeepCopy() *TopologyNodes
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TopologyNodes.
func (*TopologyNodes) DeepCopyInto ¶
func (in *TopologyNodes) DeepCopyInto(out *TopologyNodes)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TopologyRuleComponents ¶
type TopologyRuleComponents struct {
CN []StatelessTopologyRuleItem `json:"cn,omitempty"`
CDC []StatelessTopologyRuleItem `json:"cdc,omitempty"`
GMS *XStoreTopologyRule `json:"gms,omitempty"`
DN *XStoreTopologyRule `json:"dn,omitempty"`
}
func (*TopologyRuleComponents) DeepCopy ¶
func (in *TopologyRuleComponents) DeepCopy() *TopologyRuleComponents
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TopologyRuleComponents.
func (*TopologyRuleComponents) DeepCopyInto ¶
func (in *TopologyRuleComponents) DeepCopyInto(out *TopologyRuleComponents)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TopologyRules ¶
type TopologyRules struct {
Selectors []NodeSelectorItem `json:"selectors,omitempty"`
Components TopologyRuleComponents `json:"components,omitempty"`
}
func (*TopologyRules) DeepCopy ¶
func (in *TopologyRules) DeepCopy() *TopologyRules
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TopologyRules.
func (*TopologyRules) DeepCopyInto ¶
func (in *TopologyRules) DeepCopyInto(out *TopologyRules)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UpgradeStrategyType ¶
type UpgradeStrategyType string
const ( RecreateUpgradeStrategy UpgradeStrategyType = "Recreate" RollingUpgradeStrategy UpgradeStrategyType = "RollingUpgrade" )
Valid upgrade strategies.
type XStoreTemplate ¶
type XStoreTemplate struct {
// Engine of xstore. Default is operator dependent.
// +optional
Engine string `json:"engine,omitempty"`
// Image for xstore. Should be replaced by default value if not present.
// +optional
Image string `json:"image,omitempty"`
// ImagePullPolicy describes a policy for if/when to pull a container image (especially
// for the engine container).
ImagePullPolicy corev1.PullPolicy `json:"imagePullPolicy,omitempty"`
// ImagePullSecrets represents the secrets for pulling private images.
ImagePullSecrets []corev1.LocalObjectReference `json:"imagePullSecrets,omitempty"`
// Service type for xstore's service. Useful when needs an external IP.
// Default is ClusterIP.
// +optional
ServiceType corev1.ServiceType `json:"serviceType,omitempty"`
// HostNetwork mode.
// +optional
HostNetwork *bool `json:"hostNetwork,omitempty"`
// DiskQuota for xstore.
DiskQuota *resource.Quantity `json:"diskQuota,omitempty"`
// Resources. Default is limits of 4 cpu and 8Gi memory.
Resources common.ExtendedResourceRequirements `json:"resources,omitempty"`
}
func (*XStoreTemplate) DeepCopy ¶
func (in *XStoreTemplate) DeepCopy() *XStoreTemplate
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new XStoreTemplate.
func (*XStoreTemplate) DeepCopyInto ¶
func (in *XStoreTemplate) DeepCopyInto(out *XStoreTemplate)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type XStoreTopologyRule ¶
type XStoreTopologyRule struct {
Rolling *XStoreTopologyRuleRolling `json:"rolling,omitempty"`
NodeSets []XStoreTopologyRuleNodeSetItem `json:"nodeSets,omitempty"`
}
func (*XStoreTopologyRule) DeepCopy ¶
func (in *XStoreTopologyRule) DeepCopy() *XStoreTopologyRule
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new XStoreTopologyRule.
func (*XStoreTopologyRule) DeepCopyInto ¶
func (in *XStoreTopologyRule) DeepCopyInto(out *XStoreTopologyRule)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type XStoreTopologyRuleNodeSetItem ¶
type XStoreTopologyRuleNodeSetItem struct {
Name string `json:"name,omitempty"`
// +kubebuilder:validation:Enum=Candidate;Voter;Learner
Role xstore.NodeRole `json:"role,omitempty"`
// +kubebuilder:default=1
// +kubebuilder:validation:Minimum=1
Replicas int32 `json:"replicas,omitempty"`
NodeSelector *NodeSelectorReference `json:"selector,omitempty"`
}
func (*XStoreTopologyRuleNodeSetItem) DeepCopy ¶
func (in *XStoreTopologyRuleNodeSetItem) DeepCopy() *XStoreTopologyRuleNodeSetItem
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new XStoreTopologyRuleNodeSetItem.
func (*XStoreTopologyRuleNodeSetItem) DeepCopyInto ¶
func (in *XStoreTopologyRuleNodeSetItem) DeepCopyInto(out *XStoreTopologyRuleNodeSetItem)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type XStoreTopologyRuleRolling ¶
type XStoreTopologyRuleRolling struct {
Replicas int32 `json:"replicas,omitempty"`
NodeSelector *NodeSelectorReference `json:"selector,omitempty"`
}
func (*XStoreTopologyRuleRolling) DeepCopy ¶
func (in *XStoreTopologyRuleRolling) DeepCopy() *XStoreTopologyRuleRolling
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new XStoreTopologyRuleRolling.
func (*XStoreTopologyRuleRolling) DeepCopyInto ¶
func (in *XStoreTopologyRuleRolling) DeepCopyInto(out *XStoreTopologyRuleRolling)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.